@@ -1,4 +1,5 @@
 import click
+import re
 
 try:
     import ruamel_yaml as yaml
@@ -39,11 +40,7 @@ class Util:
 
     @staticmethod
     def clean(s: str):
-        s = s.replace('/', '')
-        s = s.strip()
-        if s.isidentifier():
-            s = "_" + s
-        return s
+        return re.sub('\W|^(?=\d)', '_', s)
 
 
 class OptionEatAll(click.Option):
