@@ -1,42 +1,12 @@
-import json
 from ..general import ClassDomain, Label, Field, Struct, DataSample, Util
 from tqdm import tqdm
-from ..io import HardDiskBackend, FileIO
+from ..io import FileIO
+from .base_parse import BaseParse
 
 
-class DetectionParse:
-    INSTANCE_SEG_ANN_TYPE = "polygon"
-    DETECTION_ANN_TYPE = "box2d"
-    PARENT_PATTERN = "Parent"
+class DetectionParse(BaseParse):
 
-    def __init__(self, data_info_file, ann_file, separate_flag, dataset_name=None, file_client=None):
-        if file_client:
-            self.file_client = file_client
-        else:
-            self.file_client = HardDiskBackend()
-        self.separate_flag = separate_flag
-        self._dataset_name = dataset_name
-        self._data_info_file = data_info_file
-        self._annotation_file = ann_file
-        self._data_info = self._read_json(data_info_file)
-        self._annotation_info = self._read_json(ann_file)
-        self._meta_info = self._parse_meta_info()
-        self._parent_class_domain, self._class_domain, self.raw_class_info = self._parse_class_domain()  # 父类的class domain和子类的class domain
-        self._dsdl_version_info = {"$dsdl-version": "0.5.0"}
-        self._struct_defs, self._samples = self._parse_ann_info()
-
-    def _parse_meta_info(self):
-        """
-        提取数据集元信息
-        :return: 元信息字典
-        """
-        meta_info = {k: v for k, v in self._data_info.items() if k not in ("tasks", "statistics")}
-        meta_info["sub_dataset_name"] = self._annotation_info["sub_dataset_name"]
-        if not self._dataset_name:
-            self._dataset_name = meta_info["dataset_name"]
-        return meta_info
-
-    def _parse_class_domain(self):
+    def parse_class_domain(self):
         """
         提取class domain相关的信息
         :return: 父类class domain对象，子类class domain对象，class原始信息字典
@@ -64,14 +34,16 @@ class DetectionParse:
                     label_obj.add_supercategory(super_label)  # 添加父类
         if parent_class_domain:
             class_domain.set_parent(parent_class_domain)
-            return parent_class_domain, class_domain, raw_class_info
+            return parent_class_domain, class_domain, raw_class_info, None
         else:
-            return None, class_domain, raw_class_info
+            return None, class_domain, raw_class_info, None
 
-    def _parse_ann_info(self):
+    def parse_ann_info(self):
         samples = self._annotation_info["samples"]
         object_struct = Struct("LocalObjectEntry")
+        object_struct.set_arg("cdom")  # object struct有一个形参 cdom
         sample_struct = Struct("ObjectDetectionSample")
+        sample_struct.set_arg("cdom") # sample struct 有一个形参 cdom
         media_field = Field("media", field_type="media")
         sample_struct.add_field(media_field)  # 添加图像field
         sample_container = DataSample(sample_struct, self._class_domain)
@@ -113,7 +85,7 @@ class DetectionParse:
                     continue
                 # 创建LabelField并将值装进gt_item里面
                 if 'categories' in gt and len(gt['categories']) > 0:
-                    label_field = Field("category", field_type="category", param=f"${object_struct.ARG}")
+                    label_field = Field("category", field_type="category", param=f"${object_struct.args[0]}")
                     object_struct.add_field(label_field)
                     category_id = gt.pop("categories")[0]["category_id"]
                     category_name = self.raw_class_info[gt_type][category_id]  # 拿到category_name
@@ -149,73 +121,4 @@ class DetectionParse:
                 sample_struct.set_optional("annotations")
             return (object_struct, sample_struct), sample_container
         else:
-            return (sample_struct,), sample_container
-
-    def _read_json(self, file, encoding="utf-8"):
-        bytes_info = self.file_client.get(file)
-        try:
-            text = bytes_info.decode(encoding)
-        except Exception as e:
-            raise RuntimeError(f"Failed to read '{file}'. {e}") from None
-
-        try:
-            json_info = json.loads(text)
-        except Exception as e:
-            raise RuntimeError(f"Failed to load JSON file '{file}'. {e}") from None
-        return json_info
-
-    @property
-    def struct_defs(self):
-        """
-        dsdl的struct定义字典组成的列表
-        """
-        return self._struct_defs
-
-    @property
-    def samples(self):
-        """
-        dsdl的data字段下的内容，为一个字典，有sample-type域samples字段，samples包含了样本列表
-        """
-        return self._samples
-
-    @property
-    def sample_info(self):
-        """
-        tunas v0.3的annotation的json文件的原始内容
-        """
-        return self._annotation_info
-
-    @property
-    def class_domain_info(self):
-        """
-        dsdl的class_domain的定义字典
-        """
-        return self._parent_class_domain, self._class_domain
-
-    @property
-    def meta_info(self):
-        """
-        dsdl的元信息内容
-        """
-        return self._meta_info
-
-    @property
-    def data_info_file(self):
-        """
-        返回tunas v0.3 dataset_info.json的文件路径
-        """
-        return self._data_info_file
-
-    @property
-    def annotation_file(self):
-        """
-        返回tunas v0.3 的标注文件json文件的路径
-        """
-        return self._annotation_file
-
-    @property
-    def dsdl_version(self):
-        """
-        dsdl的版本信息字典
-        """
-        return self._dsdl_version_info
+            return (sample_struct,), [self._class_domain], sample_container
\ No newline at end of file
